#
# spec file for package dash
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2013 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dash
Version:        0.5.11.2
Release:        lp151.3.6.1
Summary:        POSIX-compliant Implementation of /bin/sh
License:        BSD-3-Clause
Group:          System/Shells
URL:            http://gondor.apana.org.au/~herbert/dash/
Source:         http://gondor.apana.org.au/~herbert/dash/files/dash-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: https://git.kernel.org/pub/scm/utils/dash/dash.git/commit/?id=29d6f2148f10213de4e904d515e792d2cf8c968e
Patch1:         check-nflag-in-evaltree.patch
BuildRequires:  libedit-devel

%description
DASH is a POSIX-compliant implementation of /bin/sh that aims to be as small as
possible without sacrificing speed where possible.

%prep
%setup -q
%autopatch -p1

%build
%global optflags %{optflags} -fcommon
%configure \
	--enable-fnmatch \
	--enable-glob \
	--with-libedit
%make_build

%install
%make_install
# compatibility symlink to /bin
mkdir -p %{buildroot}/bin
ln -s %{_bindir}/dash %{buildroot}/bin/dash

%files
%license COPYING
%doc ChangeLog
%{_bindir}/dash
/bin/dash
%{_mandir}/man1/dash.1%{?ext_man}

%changelog
* Thu Nov 19 2020 Dirk Mueller <dmueller@suse.com>
- add check-nflag-in-evaltree.patch (bsc#1178978)
* Sun Oct 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.11.2 (bsc#1177691):
  * shell: Group readdir64/dirent64 with open64
- add LICENSE file
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.11.1:
  * For complete list of changes see:
    https://git.kernel.org/pub/scm/utils/dash/dash.git/log/?qt=range&q=v0.5.10..v0.5.11.1
* Tue Mar 31 2020 Martin Liška <mliska@suse.cz>
- Add -fcommon to %%optflags in order to fix boo#1160260.
* Thu Oct 25 2018 sean@suspend.net
- update to version 0.5.10
  * For complete list of changes, see:
    https://git.kernel.org/pub/scm/utils/dash/dash.git/log/?qt=range&q=v0.5.9.1..v0.5.10
- remove upstreamed patches:
  * drop dash-0.5.7-do-not-close-stderr.patch
  * drop dash-remove-backslash-before-in-double-quotes-in-variable.patch
* Sat Nov  4 2017 aavindraa@gmail.com
- update to version 0.5.9.1 (bsc#1177691)
  * For complete list of changes, see:
    https://git.kernel.org/pub/scm/utils/dash/dash.git/log/?qt=range&q=v0.5.8..v0.5.9.1
- lint with spec-cleaner
* Thu Apr  9 2015 mpluskal@suse.com
- Use fnmatch and glob from glibc
- Use url for source
* Fri Oct 10 2014 gber@opensuse.org
- update to version 0.5.8
  - Small optimisation of command -pv change
  - Set command -p path to /usr/sbin:/usr/bin:/sbin:/bin
  - Change "characters" for printf precision to "bytes"
  - Clarify "trap '' signals" syntax in manual page
  - Clarify that 0 and EXIT are both acceptable for exit traps
  - command: allow combining -p with -v
  - getjob: Fix off-by-one error for multiple of four job numbers
  - Propagate EXP_QPAT in subevalvar
  - Initialise OPTIND after importing environment
  - Fixed argument parsing crash in test
  - Add newline when tracing in poplocalvars
  - Markup fixes in manual for mandoc 1.12.1
  - Use PRIdMAX instead of %%j in printf
  - Fix typo for wait in manual
  - Add support for ulimit -r
  - Avoid overflow for very long variable name
  - Sanitise environment variable names on entry
  - Allow building without LINEO support
  - Add top-level autogen.sh
  - Avoid imaxdiv when only one of the results is wanted
  - Fix klibc DEBUG compilation
  - Merge SKIPFUNC/SKIPFILE and only clear SKIPFUNC when leaving
    dotcmd
* Fri Sep 27 2013 gber@opensuse.org
- install into %%{_bindir} and add a compatibility symlink to /bin
- reenable commandline editor
* Thu Oct  6 2011 gber@opensuse.org
- remove libeditline dependency again as libeditline lives in /usr
* Thu Oct  6 2011 gber@opensuse.org
- update to version 0.5.7
  - optimize dash -c "command" to avoid a fork
  - improve LINENO support
  - dotcmd should exit with zero when doing nothing
  - replace GPL noclobberopen code with the FreeBSD version
  - do not split the result of tilde expansion
  - use exit status 127 when the script to run does not exist
  - document optional open parenthesis for case patterns
  - use faccessat if available
- added dash-0.5.7-do-not-close-stderr.patch in order to prevent
  stderr from being closed when /dev/tty fails to open (backported
  from upstream git)
- added
  dash-remove-backslash-before-in-double-quotes-in-variable.patch
  which removes a backslash before } in double-quotes in variable
  as it prevents the closing brace from terminating the
  substitution (from FreeBSD/Debian)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Jul 19 2010 guido+opensuse.org@berhoerster.name
- update to version 0.5.6.1
  - bugfixes
* Fri Feb 19 2010 guido+opensuse.org@berhoerster.name
- cleaned up specfile
* Sat Feb 13 2010 guido+opensuse.org@berhoerster.name
- do not provide ash
* Sat Feb 13 2010 guido+opensuse.org@berhoerster.name
- initial packaging of dash
